@@ -115,7 +115,7 @@ class LinearHistory(History):
         return super()._optimize(df)
 
 
-class RevisionData:
+class BlameData:
     """
     Class to fetch raw data about repository state at certain revision
     """
@@ -191,3 +191,61 @@ class FilesData:
         data = self._fetch()
         df = pd.DataFrame(data)
         return df
+
+
+class TagsData:
+    def __init__(self, repository: git.Repository):
+        """
+        :param path: path to a repository
+        """
+        self.repo = repository
+        self.mailmap = git.Mailmap.from_repository(self.repo)
+
+    @Timeit("Fetching tags info")
+    def fetch(self):
+        # TODO: this should perhaps be a part of WholeHistory
+        tag_refs = {refobj.peel().oid: refobj
+                    for refobj in self.repo.listall_reference_objects() if refobj.name.startswith('refs/tags')}
+
+        result = []
+        tag_ref = None
+        is_symbolic_reference = False
+        for commit in self.repo.walk(self.repo.head.target, git.GIT_SORT_TOPOLOGICAL):
+            author_name, _ = map_signature(self.mailmap, commit.author)
+            if commit.oid in tag_refs:
+                tag_ref: git.Reference = tag_refs[commit.oid]
+                is_symbolic_reference = tag_ref.target.hex == commit.hex
+
+            if tag_ref is not None:
+                if not is_symbolic_reference:
+                    tag = self.repo[tag_ref.target]
+                    tagger_name, _ = map_signature(self.mailmap, tag.tagger)
+                    tag_metadata = {
+                        "tag_name": tag.name,
+                        "tagger_name": tagger_name,
+                        "tagger_time": tag.tagger.time,
+                    }
+                else:
+                    tag_metadata = {
+                        "tag_name": tag_ref.shorthand,
+                        "tagger_name": None,
+                        "tagger_time": -1,
+                    }
+            else:
+                tag_metadata = {
+                    "tag_name": None,
+                    "tagger_name": None,
+                    "tagger_time": -1,
+                }
+            tag_metadata["commit_author"] = author_name
+            tag_metadata["commit_time"] = commit.author.time
+            tag_metadata["is_merge"] = len(commit.parents) > 1
+            result.append(tag_metadata)
+
+        return result
+
+    def as_dataframe(self):
+        raw_data = pd.DataFrame(self.fetch())
+        # TODO: optimize memory by changing some datatypes
+        # .astype('bool')
+        return raw_data
